@@ -1,7 +1,12 @@
+""""
+BACKWARD COMPITABILITY!!!!!
+"""
+
 #############################
 # Sas support functions import
 #############################
-from .core import get_objects_from_spk, get_connection_from_vault, get_secret_from_vault, check_import, redeploy_jobs, \
+from .vault.vault import get_connection_from_vault, get_secret_from_vault
+from .sas.core import get_objects_from_spk, check_import, redeploy_jobs, \
     launch_sas_code, import_spk, check_sas_code
 #############################
 # Platform connectors import
@@ -17,4 +22,10 @@ from .bo import parse_dfx
 #############################
 # Win task parser
 #############################
-from .taskparser import XMLScheduledTask
+from .windows import XMLScheduledTask
+
+
+""""
+BACKWARD COMPITABILITY END.
+"""
+
