@@ -1,4 +1,4 @@
-from .core import AbstractSAS
+from .sas.core import AbstractSAS
 from .globals import sasoa_sasobjsp_host, sasoa_sasobjsp_port, sasoa_sasapp_workspace
 
 
